@@ -86,7 +86,7 @@
 #define KPARTS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPARTS_NO_DEPRECATED
-#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54200
+#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54c00
 #endif
 #ifdef KPARTS_NO_DEPRECATED_WARNINGS
 #  define KPARTS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPARTS_DEPRECATED_WARNINGS_SINCE KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x54200
+#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x54c00
 #  endif
 #endif
 
@@ -127,9 +127,16 @@
 #else
 #  define KPARTS_DEPRECATED_VERSION_5_0(text)
 #endif
+
+#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x54800
+#  define KPARTS_DEPRECATED_VERSION_5_72(text) KPARTS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KPARTS_DEPRECATED_VERSION_5_72(text)
+#endif
 #define KPARTS_DEPRECATED_VERSION_3(minor, text)      KPARTS_DEPRECATED_VERSION_3_##minor(text)
 #define KPARTS_DEPRECATED_VERSION_4(minor, text)      KPARTS_DEPRECATED_VERSION_4_##minor(text)
 #define KPARTS_DEPRECATED_VERSION_5(minor, text)      KPARTS_DEPRECATED_VERSION_5_##minor(text)
 #define KPARTS_DEPRECATED_VERSION(major, minor, text) KPARTS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
+#define KPARTS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KPARTS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 
 #endif /* KPARTS_EXPORT_H */
